<?php
/**
* Implements example command.
* @version alpha-0.1
*/
use \Pantheon\Utils;

class LaunchCheck extends WP_CLI_Command {
  public $fs;
  public $skipfiles = array();
  public $output = array();

  /**
  * run all checks
  *
  * ## OPTIONS
  *
  */
  public function all($args, $assoc_args) {
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    Utils::set('format',$format);
    $searcher = new \Pantheon\Filesearcher(getcwd().'/wp-content');
    $searcher->register( new \Pantheon\Checks\Sessions() );
    $searcher->register( new \Pantheon\Checks\Insecure() );
    $searcher->register( new \Pantheon\Checks\Exploited() );
    $searcher->execute();
    $checker = new \Pantheon\Checker();
    $checker->register( new \Pantheon\Checks\Plugins( isset($assoc_args['all'])) );
    $checker->register( new \Pantheon\Checks\Objectcache() );
    $checker->execute();
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    \Pantheon\Messenger::emit($format);
  }

  /**
  * checks for object caching
  *
  * ## OPTIONS
  *
  * [--format=<format>]
  * : output as json
  *
  * ## EXAMPLES
  *
  *   wp launchcheck object-cache
  *
  * @alias object-cache
  */
  public function object_cache($args, $assoc_args) {
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    Utils::set('format',$format);
    $checker = new \Pantheon\Checker();
    $checker->register( new \Pantheon\Checks\Objectcache() );
    $checker->execute();
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    \Pantheon\Messenger::emit($format);
  }

  /**
  * checks files for insecure code and checks the wpvulndb.com/api for known vulnerabilities
  *
  * ## OPTIONS
  *
  * [--skip=<regex>]
  * : a regular expression matching directories to skip
  *
  * [--format=<format>]
  * : output as json
  *
  * ## EXAMPLES
  *
  *   wp secure --skip=wp-content/themes
  *
  */
  public function secure($args, $assoc_args) {
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    Utils::set('format',$format);
    $searcher = new \Pantheon\Filesearcher(getcwd().'/wp-content');
    $searcher->register( new \Pantheon\Checks\Insecure() );
    $searcher->register( new \Pantheon\Checks\Exploited() );
    $searcher->execute();
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    \Pantheon\Messenger::emit($format);
  }

  /**
  * checks plugins for vulnerbities using the wpscan vulnerability DB
  * - https://wpvulndb.com/api
  *
  * ## OPTIONS
  *
  * [--all]
  * : check both active and inactive plugins ( default is active only )
  *
  * [--format=<format>]
  * : output as json
  *
  * ## EXAMPLES
  *
  *   wp launchcheck plugins --all
  *
  */
  public function plugins($args, $assoc_args) {
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    Utils::set('format',$format);
    $checker = new \Pantheon\Checker();
    $checker->register( new \Pantheon\Checks\Plugins( isset($assoc_args['all'])) );
    $checker->execute();
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    \Pantheon\Messenger::emit($format);
  }

  /**
  * checks the files for session_start()
  *
  * ## OPTIONS
  *
  * [--format=<format>]
  * : output as json
  *
  * ## EXAMPLES
  *
  *   wp launchcheck sessions
  *
  */
  public function sessions($args, $assoc_args) {
    $format = isset($assoc_args['format']) ? $assoc_args['format'] : 'raw';
    Utils::set('format',$format);
    $searcher = new \Pantheon\Filesearcher(getcwd().'/wp-content');
    $searcher->register( new \Pantheon\Checks\Sessions() );
    $searcher->execute();
    \Pantheon\Messenger::emit($format);
  }
}

// register our autoloader
spl_autoload_register(function($class) {
  if (class_exists($class)) return $class;
  $class = strtolower($class);
  if (strstr($class,"pantheon")) {
    $class = str_replace('\\','/',$class);
    $path = WP_CLI_ROOT."/php/".$class.'.php';
    if (file_exists($path)) {
      require_once($path);
    }
  }
});

WP_CLI::add_command( 'launchcheck', 'LaunchCheck' );
